function p = parameters


%% Physical Params
a =  0.108;      %[m] Bit-rock interaction law parameter
epsilon = 20e6;  %[Pa] Bit-rock interaction law parameter
zeta = 0.6;      %[-] Bit-rock interaction law parameter
p.N = 4;         %[-] Number of blades of the PDC bit

p.Ap = 0.0035;  %[m^2] Drill string cross sectional area
p.Jp = 1.2183e-05;  %[m^4] Drill string polar moment of inertia
p.Ac = 0.0209;  %[m^2] Drill collar cross sectional area
p.Jc = 5.1908e-05;%[m^4] Drill collar polar moment of inertia

p.Lp = 1000;       %[m] Drill string length
p.Lc = 300;       %[m] Drill collar length
% p.Lc = 100;       %[m] Drill collar length

p.E = 200e9;      %[Pa] Youngs modulus
p.G = 77e9;       %[m] Shear modulus
p.rho = 8e3;      %[kg/m3] Density

p.ka   = .3;      %[-] Axial domain damping
p.kt   = .3;      %[-] Torsional domain damping

% BC
% p.omega0 = 120/61.5*2*pi;   %[rad/s] Nominal angular velocity (found from RPM).
% p.omega0 = 13.0900/2-.1;
p.v0 = 30/3600;          %[m/s] Nominal rate of penetration (ROP)
% p.omega0 = 13.0900/2-.1;
p.omega0 = 61.5/60*2*pi;

%% Compute quantities
p.c_a = sqrt(p.E/p.rho);      %[m/s] Axial wave velocity
p.c_t = sqrt(p.G/p.rho);      %[m/s] Torsional wave velocity
p.zeta_tp = (p.Jp*p.G)/p.c_t;
p.zeta_tc = (p.Jc*p.G)/p.c_t;
p.zeta_ap = (p.Ap*p.E)/p.c_a;
p.zeta_ac = (p.Ac*p.E)/p.c_a;

% Nominal loop gains
p.Bri_a = a*zeta*epsilon*p.N;
p.Bri_t = 1/2*a^2*epsilon*p.N; %% %%%
p.K_a = p.Bri_a/p.zeta_ac;
p.K_t =  p.Bri_t /(2*p.zeta_tc);

%% Numerics params
Pt = 300;   % Number of cells in discretization
p.Pp = round(Pt * p.Lp/(p.Lp+p.Lc));    % Pipe cells
p.Pc = Pt - p.Pp;                       % Collar cells

p.xp    = linspace(0,p.Lp,p.Pp).';
p.xc    = p.Lp + linspace(0,p.Lc,p.Pc).';
p.x = [p.xp;p.xc];
%%

% CFL considerations
p.dt = .01;    % Data sampling rate
dxp = p.Lp/p.Pp;
dxc = p.Lc/p.Pc;
n = p.dt/min( dxp/max(p.c_t,p.c_a) , dxc/max(p.c_t,p.c_a) );
dt  = p.dt/n;

p.Wf = 7e4;
% p.Wf = .3e4;
p.beta = .5;
% p.K_a = 400e3 *1.5;
% p.K_t = 3.5e5 /50;
% p.K_a = 0 ;
% p.K_t = .1 ;

% BRI
p.omegaMAX = p.omega0 * 2;
dxl = dt*p.omegaMAX *p.N/(2*pi);
p.Pl = ceil(1/dxl);


%% Sub params
% p.Ks = 1e5;    % N/m
p.Ds = 3e4;      % Ns/m

%% Sim stuff
T0 = 0;
T1 = 60*1   ;
p.t = T0:p.dt:T1;
p.Nt = numel(p.t);

